# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/mainwindow.ui'
#
# Created: Tue Sep  2 17:00:02 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(880, 716)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setWindowTitle(_fromUtf8("Qt ARMSim"))
        MainWindow.setTabShape(QtGui.QTabWidget.Rounded)
        MainWindow.setDockNestingEnabled(True)
        MainWindow.setDockOptions(QtGui.QMainWindow.AllowNestedDocks|QtGui.QMainWindow.AllowTabbedDocks|QtGui.QMainWindow.AnimatedDocks)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.verticalLayout = QtGui.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.tabWidgetCode = QtGui.QTabWidget(self.centralwidget)
        self.tabWidgetCode.setMinimumSize(QtCore.QSize(400, 400))
        self.tabWidgetCode.setTabPosition(QtGui.QTabWidget.South)
        self.tabWidgetCode.setObjectName(_fromUtf8("tabWidgetCode"))
        self.tabSource = QtGui.QWidget()
        self.tabSource.setObjectName(_fromUtf8("tabSource"))
        self.verticalLayoutSource = QtGui.QVBoxLayout(self.tabSource)
        self.verticalLayoutSource.setObjectName(_fromUtf8("verticalLayoutSource"))
        self.tabWidgetCode.addTab(self.tabSource, _fromUtf8(""))
        self.tabARMSim = QtGui.QWidget()
        self.tabARMSim.setAccessibleName(_fromUtf8(""))
        self.tabARMSim.setObjectName(_fromUtf8("tabARMSim"))
        self.verticalLayoutARMSim = QtGui.QVBoxLayout(self.tabARMSim)
        self.verticalLayoutARMSim.setObjectName(_fromUtf8("verticalLayoutARMSim"))
        self.tabWidgetCode.addTab(self.tabARMSim, _fromUtf8(""))
        self.verticalLayout.addWidget(self.tabWidgetCode)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 880, 21))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName(_fromUtf8("menuFile"))
        self.menuRun = QtGui.QMenu(self.menubar)
        self.menuRun.setObjectName(_fromUtf8("menuRun"))
        self.menuHelp = QtGui.QMenu(self.menubar)
        self.menuHelp.setObjectName(_fromUtf8("menuHelp"))
        self.menu_Window = QtGui.QMenu(self.menubar)
        self.menu_Window.setObjectName(_fromUtf8("menu_Window"))
        self.menu_Edit = QtGui.QMenu(self.menubar)
        self.menu_Edit.setObjectName(_fromUtf8("menu_Edit"))
        MainWindow.setMenuBar(self.menubar)
        self.statusBar = QtGui.QStatusBar(MainWindow)
        self.statusBar.setObjectName(_fromUtf8("statusBar"))
        MainWindow.setStatusBar(self.statusBar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.toolBar.sizePolicy().hasHeightForWidth())
        self.toolBar.setSizePolicy(sizePolicy)
        self.toolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.toolBar.setObjectName(_fromUtf8("toolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.dockWidgetRegisters = QtGui.QDockWidget(MainWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockWidgetRegisters.sizePolicy().hasHeightForWidth())
        self.dockWidgetRegisters.setSizePolicy(sizePolicy)
        self.dockWidgetRegisters.setMinimumSize(QtCore.QSize(86, 108))
        self.dockWidgetRegisters.setToolTip(_fromUtf8(""))
        self.dockWidgetRegisters.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.dockWidgetRegisters.setObjectName(_fromUtf8("dockWidgetRegisters"))
        self.dockWidgetContentsRegisters = QtGui.QWidget()
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockWidgetContentsRegisters.sizePolicy().hasHeightForWidth())
        self.dockWidgetContentsRegisters.setSizePolicy(sizePolicy)
        self.dockWidgetContentsRegisters.setObjectName(_fromUtf8("dockWidgetContentsRegisters"))
        self.verticalLayout_6 = QtGui.QVBoxLayout(self.dockWidgetContentsRegisters)
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.treeViewRegisters = MyQTreeView(self.dockWidgetContentsRegisters)
        self.treeViewRegisters.setEnabled(True)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier 10 Pitch"))
        self.treeViewRegisters.setFont(font)
        self.treeViewRegisters.setFrameShape(QtGui.QFrame.NoFrame)
        self.treeViewRegisters.setFrameShadow(QtGui.QFrame.Plain)
        self.treeViewRegisters.setLineWidth(0)
        self.treeViewRegisters.setAlternatingRowColors(True)
        self.treeViewRegisters.setObjectName(_fromUtf8("treeViewRegisters"))
        self.verticalLayout_6.addWidget(self.treeViewRegisters)
        self.dockWidgetRegisters.setWidget(self.dockWidgetContentsRegisters)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dockWidgetRegisters)
        self.dockWidgetMemory = QtGui.QDockWidget(MainWindow)
        self.dockWidgetMemory.setMinimumSize(QtCore.QSize(180, 172))
        self.dockWidgetMemory.setToolTip(_fromUtf8(""))
        self.dockWidgetMemory.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.dockWidgetMemory.setObjectName(_fromUtf8("dockWidgetMemory"))
        self.dockWidgetContentsMemory = QtGui.QWidget()
        self.dockWidgetContentsMemory.setObjectName(_fromUtf8("dockWidgetContentsMemory"))
        self.dockWidgetMemoryLayout = QtGui.QVBoxLayout(self.dockWidgetContentsMemory)
        self.dockWidgetMemoryLayout.setObjectName(_fromUtf8("dockWidgetMemoryLayout"))
        self.treeViewMemory = MyQTreeView(self.dockWidgetContentsMemory)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier 10 Pitch"))
        self.treeViewMemory.setFont(font)
        self.treeViewMemory.setFrameShape(QtGui.QFrame.NoFrame)
        self.treeViewMemory.setFrameShadow(QtGui.QFrame.Plain)
        self.treeViewMemory.setLineWidth(0)
        self.treeViewMemory.setAlternatingRowColors(True)
        self.treeViewMemory.setObjectName(_fromUtf8("treeViewMemory"))
        self.dockWidgetMemoryLayout.addWidget(self.treeViewMemory)
        self.dockWidgetMemory.setWidget(self.dockWidgetContentsMemory)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dockWidgetMemory)
        self.dockWidgetMessages = QtGui.QDockWidget(MainWindow)
        self.dockWidgetMessages.setAllowedAreas(QtCore.Qt.BottomDockWidgetArea)
        self.dockWidgetMessages.setObjectName(_fromUtf8("dockWidgetMessages"))
        self.dockWidgetMessagesContents = QtGui.QWidget()
        self.dockWidgetMessagesContents.setObjectName(_fromUtf8("dockWidgetMessagesContents"))
        self.verticalLayout_5 = QtGui.QVBoxLayout(self.dockWidgetMessagesContents)
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.textEditMessages = QtGui.QTextEdit(self.dockWidgetMessagesContents)
        self.textEditMessages.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textEditMessages.sizePolicy().hasHeightForWidth())
        self.textEditMessages.setSizePolicy(sizePolicy)
        self.textEditMessages.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.textEditMessages.setWhatsThis(_fromUtf8(""))
        self.textEditMessages.setDocumentTitle(_fromUtf8(""))
        self.textEditMessages.setTextInteractionFlags(QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.textEditMessages.setObjectName(_fromUtf8("textEditMessages"))
        self.verticalLayout_5.addWidget(self.textEditMessages)
        self.dockWidgetMessages.setWidget(self.dockWidgetMessagesContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(8), self.dockWidgetMessages)
        self.actionWhats_This = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/64x64/categories/system-help.png", QtCore.QSize(64, 64))
        myicon.addFile(":/themes/oxygen/128x128/categories/system-help.png", QtCore.QSize(128, 128))
        myicon.addFile(":/themes/oxygen/32x32/categories/system-help.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/categories/system-help.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/categories/system-help.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/categories/system-help.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("system-help"), myicon)
        # END section included by add_file_icons.py
        self.actionWhats_This.setIcon(icon)
        self.actionWhats_This.setObjectName(_fromUtf8("actionWhats_This"))
        self.actionAbout_Qt_ARMSim = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/help-about.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/help-about.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/help-about.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/help-about.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("help-about"), myicon)
        # END section included by add_file_icons.py
        self.actionAbout_Qt_ARMSim.setIcon(icon)
        self.actionAbout_Qt_ARMSim.setObjectName(_fromUtf8("actionAbout_Qt_ARMSim"))
        self.actionHelp = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/help-contents.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/help-contents.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/help-contents.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/help-contents.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("help-contents"), myicon)
        # END section included by add_file_icons.py
        self.actionHelp.setIcon(icon)
        self.actionHelp.setObjectName(_fromUtf8("actionHelp"))
        self.actionAbout_ARMSim = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/help-about.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/help-about.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/help-about.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/help-about.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("help-about"), myicon)
        # END section included by add_file_icons.py
        self.actionAbout_ARMSim.setIcon(icon)
        self.actionAbout_ARMSim.setObjectName(_fromUtf8("actionAbout_ARMSim"))
        self.actionNew = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/document-new.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/document-new.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/document-new.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/document-new.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("document-new"), myicon)
        # END section included by add_file_icons.py
        self.actionNew.setIcon(icon)
        self.actionNew.setObjectName(_fromUtf8("actionNew"))
        self.actionOpen = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/document-open.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/document-open.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/document-open.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/document-open.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("document-open"), myicon)
        # END section included by add_file_icons.py
        self.actionOpen.setIcon(icon)
        self.actionOpen.setObjectName(_fromUtf8("actionOpen"))
        self.actionSave = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/document-save.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/document-save.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/document-save.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/document-save.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("document-save"), myicon)
        # END section included by add_file_icons.py
        self.actionSave.setIcon(icon)
        self.actionSave.setObjectName(_fromUtf8("actionSave"))
        self.actionSave_As = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/document-save-as.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/document-save-as.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/document-save-as.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/document-save-as.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("document-save-as"), myicon)
        # END section included by add_file_icons.py
        self.actionSave_As.setIcon(icon)
        self.actionSave_As.setObjectName(_fromUtf8("actionSave_As"))
        self.actionQuit = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/64x64/actions/application-exit.png", QtCore.QSize(64, 64))
        myicon.addFile(":/themes/oxygen/128x128/actions/application-exit.png", QtCore.QSize(128, 128))
        myicon.addFile(":/themes/oxygen/32x32/actions/application-exit.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/application-exit.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/application-exit.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/application-exit.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("application-exit"), myicon)
        # END section included by add_file_icons.py
        self.actionQuit.setIcon(icon)
        self.actionQuit.setObjectName(_fromUtf8("actionQuit"))
        self.actionReset_Registers = QtGui.QAction(MainWindow)
        self.actionReset_Registers.setObjectName(_fromUtf8("actionReset_Registers"))
        self.actionReset_Memory = QtGui.QAction(MainWindow)
        self.actionReset_Memory.setObjectName(_fromUtf8("actionReset_Memory"))
        self.actionClear_Console = QtGui.QAction(MainWindow)
        self.actionClear_Console.setObjectName(_fromUtf8("actionClear_Console"))
        self.actionRun = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/64x64/actions/system-run.png", QtCore.QSize(64, 64))
        myicon.addFile(":/themes/oxygen/128x128/actions/system-run.png", QtCore.QSize(128, 128))
        myicon.addFile(":/themes/oxygen/32x32/actions/system-run.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/system-run.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/system-run.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/system-run.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("system-run"), myicon)
        # END section included by add_file_icons.py
        self.actionRun.setIcon(icon)
        self.actionRun.setObjectName(_fromUtf8("actionRun"))
        self.actionStepInto = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/debug-step-into.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/debug-step-into.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/debug-step-into.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/debug-step-into.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("debug-step-into"), myicon)
        # END section included by add_file_icons.py
        self.actionStepInto.setIcon(icon)
        self.actionStepInto.setObjectName(_fromUtf8("actionStepInto"))
        self.actionBreakpoints = QtGui.QAction(MainWindow)
        self.actionBreakpoints.setObjectName(_fromUtf8("actionBreakpoints"))
        self.actionShow_Statusbar = QtGui.QAction(MainWindow)
        self.actionShow_Statusbar.setCheckable(True)
        self.actionShow_Statusbar.setChecked(True)
        self.actionShow_Statusbar.setObjectName(_fromUtf8("actionShow_Statusbar"))
        self.actionShow_Toolbar = QtGui.QAction(MainWindow)
        self.actionShow_Toolbar.setCheckable(True)
        self.actionShow_Toolbar.setChecked(True)
        self.actionShow_Toolbar.setObjectName(_fromUtf8("actionShow_Toolbar"))
        self.actionShow_Registers = QtGui.QAction(MainWindow)
        self.actionShow_Registers.setCheckable(True)
        self.actionShow_Registers.setChecked(True)
        self.actionShow_Registers.setObjectName(_fromUtf8("actionShow_Registers"))
        self.actionShow_Memory = QtGui.QAction(MainWindow)
        self.actionShow_Memory.setCheckable(True)
        self.actionShow_Memory.setChecked(True)
        self.actionShow_Memory.setObjectName(_fromUtf8("actionShow_Memory"))
        self.actionRestore_Default_Layout = QtGui.QAction(MainWindow)
        self.actionRestore_Default_Layout.setObjectName(_fromUtf8("actionRestore_Default_Layout"))
        self.actionPreferences = QtGui.QAction(MainWindow)
        self.actionPreferences.setObjectName(_fromUtf8("actionPreferences"))
        self.action_Undo = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-undo.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-undo.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-undo.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-undo.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-undo"), myicon)
        # END section included by add_file_icons.py
        self.action_Undo.setIcon(icon)
        self.action_Undo.setObjectName(_fromUtf8("action_Undo"))
        self.actionRedo = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-redo.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-redo.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-redo.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-redo.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-redo"), myicon)
        # END section included by add_file_icons.py
        self.actionRedo.setIcon(icon)
        self.actionRedo.setObjectName(_fromUtf8("actionRedo"))
        self.actionCut = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-cut.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-cut.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-cut.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-cut.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-cut"), myicon)
        # END section included by add_file_icons.py
        self.actionCut.setIcon(icon)
        self.actionCut.setObjectName(_fromUtf8("actionCut"))
        self.actionCopy = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-copy.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-copy.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-copy.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-copy.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-copy"), myicon)
        # END section included by add_file_icons.py
        self.actionCopy.setIcon(icon)
        self.actionCopy.setObjectName(_fromUtf8("actionCopy"))
        self.actionPaste = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/64x64/actions/edit-paste.png", QtCore.QSize(64, 64))
        myicon.addFile(":/themes/oxygen/128x128/actions/edit-paste.png", QtCore.QSize(128, 128))
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-paste.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-paste.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-paste.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-paste.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-paste"), myicon)
        # END section included by add_file_icons.py
        self.actionPaste.setIcon(icon)
        self.actionPaste.setObjectName(_fromUtf8("actionPaste"))
        self.actionSelect_All = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-select-all.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-select-all.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-select-all.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-select-all.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-select-all"), myicon)
        # END section included by add_file_icons.py
        self.actionSelect_All.setIcon(icon)
        self.actionSelect_All.setObjectName(_fromUtf8("actionSelect_All"))
        self.actionShow_Messages = QtGui.QAction(MainWindow)
        self.actionShow_Messages.setCheckable(True)
        self.actionShow_Messages.setChecked(True)
        self.actionShow_Messages.setObjectName(_fromUtf8("actionShow_Messages"))
        self.actionStepOver = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/debug-step-over.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/debug-step-over.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/debug-step-over.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/debug-step-over.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("debug-step-over"), myicon)
        # END section included by add_file_icons.py
        self.actionStepOver.setIcon(icon)
        self.actionStepOver.setObjectName(_fromUtf8("actionStepOver"))
        self.actionRestart = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/view-refresh.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/view-refresh.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/view-refresh.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/view-refresh.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("view-refresh"), myicon)
        # END section included by add_file_icons.py
        self.actionRestart.setIcon(icon)
        self.actionRestart.setObjectName(_fromUtf8("actionRestart"))
        self.actionResume = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/debug-run.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/debug-run.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/debug-run.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/debug-run.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("debug-run"), myicon)
        # END section included by add_file_icons.py
        self.actionResume.setIcon(icon)
        self.actionResume.setObjectName(_fromUtf8("actionResume"))
        self.menuFile.addAction(self.actionNew)
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSave)
        self.menuFile.addAction(self.actionSave_As)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuRun.addAction(self.actionRun)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionStepInto)
        self.menuRun.addAction(self.actionStepOver)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionRestart)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionBreakpoints)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionReset_Registers)
        self.menuRun.addAction(self.actionReset_Memory)
        self.menuRun.addAction(self.actionClear_Console)
        self.menuHelp.addAction(self.actionHelp)
        self.menuHelp.addAction(self.actionWhats_This)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout_Qt_ARMSim)
        self.menuHelp.addAction(self.actionAbout_ARMSim)
        self.menu_Window.addAction(self.actionShow_Statusbar)
        self.menu_Window.addAction(self.actionShow_Toolbar)
        self.menu_Window.addAction(self.actionShow_Registers)
        self.menu_Window.addAction(self.actionShow_Memory)
        self.menu_Window.addAction(self.actionShow_Messages)
        self.menu_Window.addSeparator()
        self.menu_Window.addAction(self.actionRestore_Default_Layout)
        self.menu_Window.addSeparator()
        self.menu_Edit.addAction(self.action_Undo)
        self.menu_Edit.addAction(self.actionRedo)
        self.menu_Edit.addSeparator()
        self.menu_Edit.addAction(self.actionCut)
        self.menu_Edit.addAction(self.actionCopy)
        self.menu_Edit.addAction(self.actionPaste)
        self.menu_Edit.addSeparator()
        self.menu_Edit.addAction(self.actionSelect_All)
        self.menu_Edit.addSeparator()
        self.menu_Edit.addAction(self.actionPreferences)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menu_Edit.menuAction())
        self.menubar.addAction(self.menu_Window.menuAction())
        self.menubar.addAction(self.menuRun.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionOpen)
        self.toolBar.addAction(self.actionSave)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_Undo)
        self.toolBar.addAction(self.actionRedo)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionRun)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionStepInto)
        self.toolBar.addAction(self.actionStepOver)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionRestart)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionWhats_This)

        self.retranslateUi(MainWindow)
        self.tabWidgetCode.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        self.tabSource.setWhatsThis(_translate("MainWindow", "The Source Code tab is used to edit the assembler source code that is going to be simmulated", None))
        self.tabWidgetCode.setTabText(self.tabWidgetCode.indexOf(self.tabSource), _translate("MainWindow", "Source Code", None))
        self.tabARMSim.setWhatsThis(_translate("MainWindow", "The ArmSim tab is used to inspect and simmulate the ARM machine code generated after assembling the source code", None))
        self.tabWidgetCode.setTabText(self.tabWidgetCode.indexOf(self.tabARMSim), _translate("MainWindow", "ARMSim", None))
        self.menuFile.setTitle(_translate("MainWindow", "&File", None))
        self.menuRun.setTitle(_translate("MainWindow", "&Run", None))
        self.menuHelp.setTitle(_translate("MainWindow", "Help", None))
        self.menu_Window.setTitle(_translate("MainWindow", "&View", None))
        self.menu_Edit.setTitle(_translate("MainWindow", "&Edit", None))
        self.toolBar.setWindowTitle(_translate("MainWindow", "Barra de herramientas", None))
        self.dockWidgetRegisters.setWhatsThis(_translate("MainWindow", "The Registers dock shows the contents of the registers", None))
        self.dockWidgetRegisters.setWindowTitle(_translate("MainWindow", "Registers", None))
        self.dockWidgetMemory.setWhatsThis(_translate("MainWindow", "The Memory dock shows the contents of the memory", None))
        self.dockWidgetMemory.setWindowTitle(_translate("MainWindow", "Memory", None))
        self.dockWidgetMessages.setWhatsThis(_translate("MainWindow", "The Messages dock shows Qt ARMSim and ARMSim messages", None))
        self.dockWidgetMessages.setWindowTitle(_translate("MainWindow", "Messages", None))
        self.actionWhats_This.setText(_translate("MainWindow", "What\'s &This?", None))
        self.actionWhats_This.setStatusTip(_translate("MainWindow", "¿Qué es esto?", None))
        self.actionWhats_This.setWhatsThis(_translate("MainWindow", "Activa la ayuda", None))
        self.actionWhats_This.setShortcut(_translate("MainWindow", "Shift+F1", None))
        self.actionAbout_Qt_ARMSim.setText(_translate("MainWindow", "About Qt ARMSim", None))
        self.actionAbout_Qt_ARMSim.setStatusTip(_translate("MainWindow", "Sobre spim", None))
        self.actionAbout_Qt_ARMSim.setWhatsThis(_translate("MainWindow", "Imprime en el panel mensajes información sobre XSPIM", None))
        self.actionHelp.setText(_translate("MainWindow", "Qt ArmSim &Help", None))
        self.actionHelp.setShortcut(_translate("MainWindow", "F1", None))
        self.actionAbout_ARMSim.setText(_translate("MainWindow", "About ARMSim", None))
        self.actionNew.setText(_translate("MainWindow", "&New...", None))
        self.actionNew.setShortcut(_translate("MainWindow", "Ctrl+N", None))
        self.actionOpen.setText(_translate("MainWindow", "&Open...", None))
        self.actionOpen.setToolTip(_translate("MainWindow", "Open ARM assembler file", None))
        self.actionOpen.setShortcut(_translate("MainWindow", "Ctrl+O", None))
        self.actionSave.setText(_translate("MainWindow", "&Save", None))
        self.actionSave.setShortcut(_translate("MainWindow", "Ctrl+S", None))
        self.actionSave_As.setText(_translate("MainWindow", "Save &As...", None))
        self.actionQuit.setText(_translate("MainWindow", "&Quit", None))
        self.actionQuit.setShortcut(_translate("MainWindow", "Ctrl+Q", None))
        self.actionReset_Registers.setText(_translate("MainWindow", "Reset R&egisters", None))
        self.actionReset_Memory.setText(_translate("MainWindow", "Reset &Memory", None))
        self.actionClear_Console.setText(_translate("MainWindow", "Clear &Console", None))
        self.actionRun.setText(_translate("MainWindow", "&Run", None))
        self.actionRun.setShortcut(_translate("MainWindow", "Ctrl+F11", None))
        self.actionStepInto.setText(_translate("MainWindow", "Step &Into", None))
        self.actionStepInto.setToolTip(_translate("MainWindow", "Step Into", None))
        self.actionStepInto.setShortcut(_translate("MainWindow", "F5", None))
        self.actionBreakpoints.setText(_translate("MainWindow", "&Breakpoints", None))
        self.actionBreakpoints.setShortcut(_translate("MainWindow", "Ctrl+B", None))
        self.actionShow_Statusbar.setText(_translate("MainWindow", "Show St&atusbar", None))
        self.actionShow_Toolbar.setText(_translate("MainWindow", "Show &Toolbar", None))
        self.actionShow_Registers.setText(_translate("MainWindow", "Show &Registers", None))
        self.actionShow_Memory.setText(_translate("MainWindow", "Show &Memory", None))
        self.actionRestore_Default_Layout.setText(_translate("MainWindow", "Restore Default &Layout", None))
        self.actionRestore_Default_Layout.setShortcut(_translate("MainWindow", "F3", None))
        self.actionPreferences.setText(_translate("MainWindow", "&Preferences...", None))
        self.action_Undo.setText(_translate("MainWindow", "&Undo", None))
        self.action_Undo.setShortcut(_translate("MainWindow", "Ctrl+Z", None))
        self.actionRedo.setText(_translate("MainWindow", "Re&do", None))
        self.actionRedo.setShortcut(_translate("MainWindow", "Ctrl+Shift+Z", None))
        self.actionCut.setText(_translate("MainWindow", "Cu&t", None))
        self.actionCut.setShortcut(_translate("MainWindow", "Ctrl+X", None))
        self.actionCopy.setText(_translate("MainWindow", "&Copy", None))
        self.actionCopy.setShortcut(_translate("MainWindow", "Ctrl+C", None))
        self.actionPaste.setText(_translate("MainWindow", "&Paste", None))
        self.actionPaste.setShortcut(_translate("MainWindow", "Ctrl+V", None))
        self.actionSelect_All.setText(_translate("MainWindow", "Select &All", None))
        self.actionSelect_All.setShortcut(_translate("MainWindow", "Ctrl+A", None))
        self.actionShow_Messages.setText(_translate("MainWindow", "Show M&essages", None))
        self.actionStepOver.setText(_translate("MainWindow", "Step &Over", None))
        self.actionStepOver.setToolTip(_translate("MainWindow", "Step Over", None))
        self.actionStepOver.setShortcut(_translate("MainWindow", "F6", None))
        self.actionRestart.setText(_translate("MainWindow", "Re&start", None))
        self.actionRestart.setToolTip(_translate("MainWindow", "Restart Simulation", None))
        self.actionRestart.setShortcut(_translate("MainWindow", "F4", None))
        self.actionResume.setText(_translate("MainWindow", "Resu&me", None))
        self.actionResume.setToolTip(_translate("MainWindow", "Resume Execution", None))
        self.actionResume.setShortcut(_translate("MainWindow", "F8", None))

from ..widget.myqtreeview import MyQTreeView
from ..res import oxygen_rc
